@@ -38,6 +38,19 @@
 #include <iostream>
 
 
+#ifdef __FreeBSD__   // FreeBSD
+#define s6_addr16 __u6_addr.__u6_addr16
+#define s6_addr32 __u6_addr.__u6_addr32
+#endif
+#ifdef __APPLE__   // MacOS X
+#define s6_addr16 __u6_addr.__u6_addr16
+#define s6_addr32 __u6_addr.__u6_addr32
+#endif
+#ifdef __sun   // SunOS and Solaris
+#define s6_addr16 _S6_un._S6_u16
+#define s6_addr32 _S6_un._S6_u32
+#endif
+
 
 unsigned long long getMicroTime();
 
